==> wolf-1.7.3-20161018.014758-1-sources.jar: cn/com/duiba/wolf/utils/SignUtils.java <==
package cn.com.duiba.wolf.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * 数字签名工具类,用于对参数进行加密,确保参数不会被篡改。确保发起方是可信的
 * Created by wenqi.huang on 16/5/10.
 */
public class SignUtils {

    private static final Logger logger = LoggerFactory.getLogger(SignUtils.class);

    /**
     * 使用<code>secret</code>对paramValues按以下算法进行签名： <br/>
     * lowercase(sha1(secretkey1value1key2value2...secret)
     *
     * @param paramValues 参数列表
     * @param secret
     * @return
     */
    public static String sign(Map<String, String> paramValues, String secret) {
        return sign(paramValues,null,secret);
    }

    /**
     * 对paramValues进行签名，其中ignoreParamNames这些参数不参与签名
     * @param paramValues
     * @param ignoreParamNames
     * @param secret
     * @return
     */
    public static String sign(Map<String, String> paramValues, List<String> ignoreParamNames,String secret) {
        StringBuilder sb = new StringBuilder();
        List<String> paramNames = new ArrayList<String>(paramValues.size());
        paramNames.addAll(paramValues.keySet());
        if(ignoreParamNames != null && ignoreParamNames.size() > 0){
            for (String ignoreParamName : ignoreParamNames) {
                paramNames.remove(ignoreParamName);
            }
        }
        Collections.sort(paramNames);

        sb.append(secret);
        for (String paramName : paramNames) {
            sb.append(paramName).append(paramValues.get(paramName));
        }
        sb.append(secret);
        return SecurityUtils.encode2StringBySHA(sb.toString()).toLowerCase();
    }

    public static void main(String[] args) throws IOException {
        String a = "secret12appKeytestmessageFormatjsonmethoduser.getuserId01234567890123456789012345678912v1.0secret12";
        String c = SecurityUtils.encode2StringBySHA(a);
        System.out.println(c);
    }

}

==> wolf-2.1.18-sources.jar: cn/com/duiba/wolf/utils/SignUtils.java <==
package cn.com.duiba.wolf.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * 数字签名工具类,用于对参数进行加密,确保参数不会被篡改。确保发起方是可信的
 * Created by wenqi.huang on 16/5/10.
 */
public class SignUtils {

    /**
     * 使用<code>secret</code>对paramValues按以下算法进行签名： <br/>
     * lowercase(sha1(secretkey1value1key2value2...secret)
     *
     * @param paramValues 参数列表
     * @param secret
     * @return
     */
    public static String sign(Map<String, String> paramValues, String secret) {
        return sign(paramValues,null,secret);
    }

    /**
     * 对paramValues进行签名，其中ignoreParamNames这些参数不参与签名
     * @param paramValues
     * @param ignoreParamNames
     * @param secret
     * @return
     */
    public static String sign(Map<String, String> paramValues, List<String> ignoreParamNames,String secret) {
        StringBuilder sb = new StringBuilder();
        List<String> paramNames = new ArrayList<>(paramValues.size());
        paramNames.addAll(paramValues.keySet());
        if(ignoreParamNames != null && !ignoreParamNames.isEmpty()){
            for (String ignoreParamName : ignoreParamNames) {
                paramNames.remove(ignoreParamName);
            }
        }
        Collections.sort(paramNames);

        sb.append(secret);
        for (String paramName : paramNames) {
            sb.append(paramName).append(paramValues.get(paramName));
        }
        sb.append(secret);
        return SecurityUtils.encode2StringBySHA(sb.toString()).toLowerCase();
    }

}
